@@ -81,13 +81,19 @@ class AzureBlobStorageManager(StorageManager):
         return None
 
     def put_contents(self, paths, contents, hash_value):
-        contents_md5_hash = hashlib.md5(contents)
-        logger.debug(f"Uploading a cache to Azure Blob. md5_hash={contents_md5_hash.hexdigest()}")
-        content_settings = ContentSettings(content_md5=bytearray(contents_md5_hash.digest()))
-        try:
-            self._container_client.upload_blob('/'.join(paths), contents, content_settings=content_settings, metadata={self.HASH_METADATA_NAME: hash_value}, max_concurrency=8, timeout=300)
-        except Exception as e:
-            logger.warning(f"Failed to upload cache {paths} (hash={hash_value}) due to {e}. The error is ignored.")
+        blob_client = self._container_client.get_blob_client('/'.join(paths))
+
+        if blob_client.exists():
+            logger.debug("The blob already exists. Skipping upload. Probably it was uploaded by another process.")
+        else:
+            contents_md5_hash = hashlib.md5(contents)
+            logger.debug(f"Uploading a cache to Azure Blob. md5_hash={contents_md5_hash.hexdigest()}")
+            content_settings = ContentSettings(content_md5=bytearray(contents_md5_hash.digest()))
+            try:
+                # Set overwrite=True since sometimes a blob data will be corrupted if two processes uploaded to a same blob with overwrite=False.
+                blob_client.upload_blob(contents, content_settings=content_settings, metadata={self.HASH_METADATA_NAME: hash_value}, max_concurrency=8, timeout=300, overwrite=True)
+            except Exception as e:
+                logger.warning(f"Failed to upload cache {paths} (hash={hash_value}) due to {e}. The error is ignored.")
 
 
 class FileSystemStorageManager(StorageManager):
